@@ -13,7 +13,8 @@ notest <- function(x, x.by, ...)
 ## For now, just write our own to avoid over-writing anova R-base function
 ## also, nice to keep same format to call, eval(call(function, x, x,by)), as other tests
 anova <- function(x, x.by, ...) {
-  if(any(table(is.na(x), x.by)[1, ] == 0)) {
+  tab <- table(is.na(x), x.by)
+  if(any(tab[1, ] == 0) || any(colSums(tab) == 0)) {
     return(list(p.value=NA_real_, statistic.F=NA_real_, method="Linear Model ANOVA"))
   }
   aov.out <- stats::lm(x~x.by)
@@ -24,7 +25,8 @@ anova <- function(x, x.by, ...) {
 }
 ## 2. kruskal-wallis (non-parametric)
 kwt <- function(x, x.by, ...) {
-  if(any(table(is.na(x), x.by)[1, ] == 0)) {
+  tab <- table(is.na(x), x.by)
+  if(any(tab[1, ] == 0) || any(colSums(tab) == 0)) {
     return(list(p.value=NA_real_, statistic.F=NA_real_, method="Kruskal-Wallis rank sum test"))
   }
   stats::kruskal.test(x, as.factor(x.by))
@@ -61,7 +63,8 @@ trend <- function(x, x.by, ...) {
 ## ' @param x.by  by, categorical variable
 ## ' @return   test output with $method and $p.value
 logrank <- function(x, x.by, ...) {
-  if(any(table(is.na(x), x.by)[1, ] == 0)) {
+  tab <- table(is.na(x), x.by)
+  if(any(tab[1, ] == 0) || any(colSums(tab) == 0)) {
     return(list(p.value=NA_real_, method="survdiff logrank"))
   }
   out <- survival::survdiff(x ~ x.by)
